@@ -32,15 +32,15 @@ CONFIG = [
 
 if __name__ == "__main__":
     from argparse import ArgumentParser
-    from limic.util import set_verbosity, parse_config, set_parser, set_md5sum, set_overwrite
+    from limic.util import set_option, parse_config
     from importlib import import_module
     parser = ArgumentParser(description="Powerlines as drone highways.")
     parse_config(CONFIG, parser, [])
     args = parser.parse_args()
-    set_verbosity(args.verbosity)
-    set_md5sum(not args.md5sum)
-    set_overwrite(args.overwrite)
-    set_parser(parser)
+    set_option('verbosity',args.verbosity)
+    set_option('md5sum',not args.md5sum)
+    set_option('overwrite',args.overwrite)
+    set_option('parser',parser)
     module = import_module(args.mod)
     func = vars(module)[args.func]
     del args.verbosity, args.md5sum, args.overwrite, args.mod, args.func, args.command
