@@ -47,7 +47,7 @@ def test(overpass_url,no_gt):
     import limic.prune as prune
     import limic.select as select
     import limic.length as length
-    util.set_overwrite(True)
+    util.set_option('overwrite',True)
     countries = COUNTRIES
     osm_countries = OSM_COUNTRIES
     idss = IDSS
